Contributing
------------

Pull requests (code changes / documentation / typos / feature requests / setup)
are gladly accepted. If you are intending to introduce some large-scale
changes, please get in touch first to make sure we're on the same page: try to
include a docstring for any new method or class, and keep method bodies small,
readable and PEP8-compliant. Add tests and strive to keep the code coverage
levels high.

GitHub
^^^^^^
The source code is available to clone at: https://github.com/rm-hull/luma.core.git

Contributors
^^^^^^^^^^^^
* Thijs Triemstra (@thijstriemstra)
* Christoph Handel (@fragfutter)
* Boeeerb (@Boeeerb)
* xes (@xes)
* Roger Dahl (@rogerdahl)
* Václav Šmilauer (@eudoxos)
* Claus Bjerre (@bjerrep)
